==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationExecutionEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapAuthenticationExecutionEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setId((String) value);
        }
    },
    AUTHENTICATOR {
        public static final String FIELD_NAME = "Authenticator";
        public static final String FIELD_NAME_DASHED = "authenticator";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setAuthenticator((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getAuthenticator();
        }
    },
    AUTHENTICATOR_CONFIG {
        public static final String FIELD_NAME = "AuthenticatorConfig";
        public static final String FIELD_NAME_DASHED = "authenticator-config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setAuthenticatorConfig((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getAuthenticatorConfig();
        }
    },
    AUTHETICATOR_FLOW {
        public static final String FIELD_NAME = "AutheticatorFlow";
        public static final String FIELD_NAME_DASHED = "autheticator-flow";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (Boolean) e.isAutheticatorFlow();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setAutheticatorFlow((Boolean) value);
        }
    },
    FLOW_ID {
        public static final String FIELD_NAME = "FlowId";
        public static final String FIELD_NAME_DASHED = "flow-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getFlowId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setFlowId((String) value);
        }
    },
    PARENT_FLOW_ID {
        public static final String FIELD_NAME = "ParentFlowId";
        public static final String FIELD_NAME_DASHED = "parent-flow-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setParentFlowId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getParentFlowId();
        }
    },
    PRIORITY {
        public static final String FIELD_NAME = "Priority";
        public static final String FIELD_NAME_DASHED = "priority";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (Integer) e.getPriority();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setPriority((Integer) value);
        }
    },
    REQUIREMENT {
        public static final String FIELD_NAME = "Requirement";
        public static final String FIELD_NAME_DASHED = "requirement";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.models.AuthenticationExecutionModel.Requirement.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.models.AuthenticationExecutionModel.Requirement get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (org.keycloak.models.AuthenticationExecutionModel.Requirement) e.getRequirement();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setRequirement((org.keycloak.models.AuthenticationExecutionModel.Requirement) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationExecutionEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapAuthenticationExecutionEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getId();
        }
    },
    AUTHENTICATOR {
        public static final String FIELD_NAME = "Authenticator";
        public static final String FIELD_NAME_DASHED = "authenticator";
        public static final String FIELD_NAME_CAMEL_CASE = "authenticator";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getAuthenticator();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setAuthenticator((String) value);
        }
    },
    AUTHENTICATOR_CONFIG {
        public static final String FIELD_NAME = "AuthenticatorConfig";
        public static final String FIELD_NAME_DASHED = "authenticator-config";
        public static final String FIELD_NAME_CAMEL_CASE = "authenticatorConfig";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setAuthenticatorConfig((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getAuthenticatorConfig();
        }
    },
    AUTHETICATOR_FLOW {
        public static final String FIELD_NAME = "AutheticatorFlow";
        public static final String FIELD_NAME_DASHED = "autheticator-flow";
        public static final String FIELD_NAME_CAMEL_CASE = "autheticatorFlow";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setAutheticatorFlow((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (Boolean) e.isAutheticatorFlow();
        }
    },
    FLOW_ID {
        public static final String FIELD_NAME = "FlowId";
        public static final String FIELD_NAME_DASHED = "flow-id";
        public static final String FIELD_NAME_CAMEL_CASE = "flowId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setFlowId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getFlowId();
        }
    },
    PARENT_FLOW_ID {
        public static final String FIELD_NAME = "ParentFlowId";
        public static final String FIELD_NAME_DASHED = "parent-flow-id";
        public static final String FIELD_NAME_CAMEL_CASE = "parentFlowId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setParentFlowId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (String) e.getParentFlowId();
        }
    },
    PRIORITY {
        public static final String FIELD_NAME = "Priority";
        public static final String FIELD_NAME_DASHED = "priority";
        public static final String FIELD_NAME_CAMEL_CASE = "priority";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setPriority((Integer) value);
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (Integer) e.getPriority();
        }
    },
    REQUIREMENT {
        public static final String FIELD_NAME = "Requirement";
        public static final String FIELD_NAME_DASHED = "requirement";
        public static final String FIELD_NAME_CAMEL_CASE = "requirement";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.models.AuthenticationExecutionModel.Requirement.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.models.AuthenticationExecutionModel.Requirement get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e) {
            return (org.keycloak.models.AuthenticationExecutionModel.Requirement) e.getRequirement();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity e, T value) {
            e.setRequirement((org.keycloak.models.AuthenticationExecutionModel.Requirement) value);
        }
    },
}
